-- Izbris vseh ročno premaknjenih plovil, ki niso dejansko prisotna, saj bomo od sedaj naprej v tej tabeli vodili samo ročne premike trenutne situacije marine
ALTER TABLE PLOVILA_SVG
DROP CONSTRAINT PLOVILA_SVG_PK;

DELETE FROM PLOVILA_SVG
WHERE PRISOTNO != 1;

DELETE FROM PLOVILA_SVG
WHERE ID NOT IN (0, -1);

-- Izbris vseh stolpcev, ki jih ne potrebujemo več, po novem potrebujemo samo ID_PLOVILA
ALTER TABLE PLOVILA_SVG
DROP COLUMN ID;

ALTER TABLE PLOVILA_SVG
DROP COLUMN PRISOTNO;

ALTER TABLE PLOVILA_SVG
DROP COLUMN ID_PRESPR;

-- Dodamo PK na ID_PLOVILA. Zapisi morajo biti unikatni, saj smo vse premike neprisotnih plovil predhodno pobrisali.
ALTER TABLE PLOVILA_SVG
ADD CONSTRAINT PLOVILA_SVG_PK PRIMARY KEY (ID_PLOVILA);

-- Kreiranje novega pogleda, preko katerega bomo dostopali samo do trenutne dejanske situacije (brez SVG povezave)
CREATE OR REPLACE VIEW V_PLOVILA AS (
	SELECT PR.ID_PRIVEZI, PL.ID AS ID_PLOVILA, NVL(TRUNC(PL.TRENUTNO_OD), TRUNC(SYSDATE)) AS DATUM_OD, NVL(TRUNC(PL.TRENUTNO_DO), TRUNC(SYSDATE)+ 1) AS DATUM_DO, 
	PR.ID_PRIVEZ, N.OBJEKT, N.N_PRIVEZA, PL.IME AS IME_PLOVILA, PL.NTIP AS TIP_PLOVILA, PL.DOLZINA AS DOLZINA_PLOVILA, PL.SIRINA AS SIRINA_PLOVILA, K.ID AS ID_LASTNIKA, K.IME AS IME_KUPCI, K.PRIIMEK AS PRIIMEK_KUPCI, K.SALDAKONTI_SIT,
	(CASE WHEN PL.POGODBENI_OBJEKT_PRIVEZA IS NOT NULL THEN 'PO' ELSE 'TR' END) AS VRSTA_PLOVILA
	FROM PRIVEZI PR
	JOIN PLOVILA PL ON PL.ID = PR.ID_PLOVILA
	JOIN KUPCI K ON K.ID = PL.ID_LASTNIKA
	JOIN NNPRIVEZ N ON N.ID_PRIVEZ = PR.ID_PRIVEZ
	WHERE PR.ID_POGODBE IS NULL
);

-- Kreiranje novega pogleda, preko katerega bomo dostopali samo do trenutne dejanske situacije (s SVG povezavo)
CREATE OR REPLACE VIEW V_PLOVILA_SVG AS (
	SELECT V.ID_PRIVEZI, V.ID_PLOVILA, V.DATUM_OD, V.DATUM_DO, V.ID_PRIVEZ, V.OBJEKT, V.N_PRIVEZA, V.IME_PLOVILA, V.TIP_PLOVILA, V.DOLZINA_PLOVILA, V.SIRINA_PLOVILA, V.ID_LASTNIKA,
	V.IME_KUPCI, V.PRIIMEK_KUPCI, V.SALDAKONTI_SIT, V.VRSTA_PLOVILA,
	PS.TRANS_X AS TRANS_X_PLOVILA, PS.TRANS_Y AS TRANS_Y_PLOVILA, PS.ROT_DEGREES AS ROT_DEGREES_PLOVILA, NS.DOLZINA AS DOLZINA_PRIVEZA, NS.SIRINA AS SIRINA_PRIVEZA, 
	NS.TRANS_X AS TRANS_X_PRIVEZA, NS.TRANS_Y AS TRANS_Y_PRIVEZA, NS.ROT_DEGREES AS ROT_DEGREES_PRIVEZA
	FROM V_PLOVILA V
	JOIN NNPRIVEZ_SVG NS ON NS.ID_PRIVEZ = V.ID_PRIVEZ
	LEFT JOIN PLOVILA_SVG PS ON PS.ID_PLOVILA = V.ID_PLOVILA
);

-- Kreiranje novega pogleda, preko katerega bomo lahko izpisovali proste priveze, skupaj s plovili na njih (samo trenutna situacija)
CREATE OR REPLACE VIEW V_NNPRIVEZ_PLOVILA AS (
	SELECT DISTINCT NN.ID_PRIVEZ || '-' || V.ID_PRIVEZI AS ID, NN.ID_PRIVEZ, NN.OBJEKT, NN.KATEGORIJA, NN.N_PRIVEZA, NN.DOLZINA, NN.SIRINA, NN.VISINA, NN.GLOBINA, NN.LIMIT, NN.ZASEDENO,
	V.ID_PRIVEZI, V.ID_PLOVILA, V.ID_LASTNIKA, V.DATUM_OD, V.DATUM_DO, V.IME_PLOVILA, V.PRIIMEK_KUPCI, V.IME_KUPCI
	FROM NNPRIVEZ NN
	LEFT OUTER JOIN V_PLOVILA V ON V.ID_PRIVEZ = NN.ID_PRIVEZ
);

-- Popravek pogleda V_REZERVAC, odstranjen stolpec PRISOTNO, narejen JOIN na tabelo KUPCI, dodan ID_POGODBE in TIP_PLOVILA_LONG
CREATE OR REPLACE VIEW V_REZERVAC AS (
	SELECT R.ID, D.ID_REZERVAC_DETAIL, R.ID_POGODBE, D.DATUM_OD AS DATUM_REZERVACIJE, D.DATUM_DO, 
	NP.OBJEKT AS NOBJEKT, NP.N_PRIVEZA AS PRIVEZ, D.ID_PRIVEZ, R.VRSTA, R.STATUS_REZERVAC, R.ID_LASTNIKA, R.ID_PLOVILA, 
	(CASE WHEN R.ID_LASTNIKA IS NULL OR R.ID_LASTNIKA = 0 THEN R.NAZIV ELSE K.PRIIMEK END) AS NAZIV, 
	(CASE WHEN R.ID_LASTNIKA IS NULL OR R.ID_LASTNIKA = 0 THEN R.PRIIMEK ELSE K.PRIIMEK END) AS PRIIMEK,
	(CASE WHEN R.ID_LASTNIKA IS NULL OR R.ID_LASTNIKA = 0 THEN R.IME ELSE K.IME END) AS IME, K.SALDAKONTI_SIT,
	(CASE WHEN R.ID_PLOVILA IS NULL OR R.ID_PLOVILA = 0 THEN R.PLOVILO ELSE P.IME END) AS PLOVILO, 
	(CASE WHEN R.ID_PLOVILA IS NULL OR R.ID_PLOVILA = 0 THEN R.DOLZINA ELSE P.DOLZINA END) AS DOLZINA,
	(CASE WHEN R.ID_PLOVILA IS NULL OR R.ID_PLOVILA = 0 THEN R.SIRINA ELSE P.SIRINA END) AS SIRINA,
	(CASE WHEN R.ID_PLOVILA IS NULL OR R.ID_PLOVILA = 0 THEN R.GREZ ELSE P.GREZ END) AS GREZ,
	(CASE WHEN R.ID_PLOVILA IS NULL OR R.ID_PLOVILA = 0 THEN 'J' ELSE P.NTIP END) AS NTIP,
	(CASE WHEN R.ID_PLOVILA IS NULL OR R.ID_PLOVILA = 0 THEN (SELECT OPIS FROM NNTIP WHERE SIFRA = 'J') ELSE NT.OPIS END) AS TIP_PLOVILA_LONG
	FROM REZERVAC R
	JOIN REZERVAC_DETAIL D ON R.ID=D.ID_REZERVAC 
	LEFT OUTER JOIN NNPRIVEZ NP ON D.ID_PRIVEZ=NP.ID_PRIVEZ 
	LEFT OUTER JOIN KUPCI K ON K.ID = R.ID_LASTNIKA
	LEFT OUTER JOIN PLOVILA P ON P.ID = R.ID_PLOVILA
	LEFT OUTER JOIN NNTIP NT ON NT.SIFRA = P.NTIP
	WHERE R.STORNO IS NULL AND R.DATUM_DO IS NOT NULL
);

-- Popravek pogleda V_REZERVAC_SVG, odstranjen stolpec PRISOTNO, dodan ID_POGODBE, odstranitev default nastavitve tipa za plovilo
CREATE OR REPLACE VIEW V_REZERVAC_SVG AS (
	SELECT DISTINCT V.ID, V.ID_REZERVAC_DETAIL, V.ID_POGODBE, V.DATUM_REZERVACIJE, V.DATUM_DO, V.ID_LASTNIKA, V.ID_PLOVILA, V.ID_PRIVEZ, V.PRIIMEK AS PRIIMEK_LASTNIKA, V.IME AS IME_LASTNIKA, 
	V.PLOVILO AS IME_PLOVILA, V.NTIP AS TIP_PLOVILA, V.DOLZINA AS DOLZINA_PLOVILA, V.SIRINA AS SIRINA_PLOVILA, RD.TRANS_X AS TRANS_X_PLOVILA, RD.TRANS_Y AS TRANS_Y_PLOVILA, 
	RD.ROT_DEGREES AS ROT_DEGREES_PLOVILA, NS.DOLZINA AS DOLZINA_PRIVEZA, NS.SIRINA AS SIRINA_PRIVEZA, NS.TRANS_X AS TRANS_X_PRIVEZA, NS.TRANS_Y AS TRANS_Y_PRIVEZA, NS.ROT_DEGREES AS ROT_DEGREES_PRIVEZA, N.OBJEKT,
	V.VRSTA AS VRSTA_REZERVACIJE, V.STATUS_REZERVAC AS STATUS_REZERVACIJE
	FROM V_REZERVAC V
	JOIN NNPRIVEZ N ON N.ID_PRIVEZ = V.ID_PRIVEZ
	JOIN NNPRIVEZ_SVG NS ON NS.ID_PRIVEZ = V.ID_PRIVEZ
	LEFT JOIN REZERVAC_DETAIL_SVG RD ON RD.ID_REZERVAC_DETAIL = V.ID_REZERVAC_DETAIL
);

-- Popravek pogleda V_NNPRIVEZ_REZERVAC, odstranjen stolpec PRISOTNO
CREATE OR REPLACE VIEW V_NNPRIVEZ_REZERVAC AS (
	SELECT DISTINCT NN.ID_PRIVEZ || '-' || VR.ID_REZERVAC_DETAIL AS ID, NN.ID_PRIVEZ, NN.OBJEKT, NN.KATEGORIJA, NN.N_PRIVEZA, NN.DOLZINA, NN.SIRINA, NN.VISINA, NN.GLOBINA, NN.LIMIT, NN.ZASEDENO,
	VR.ID AS ID_REZERVAC, VR.ID_REZERVAC_DETAIL, VR.DATUM_REZERVACIJE, VR.DATUM_DO, VR.PLOVILO AS IME_PLOVILA, VR.PRIIMEK AS PRIIMEK_LASTNIKA, VR.IME AS IME_LASTNIKA
	FROM NNPRIVEZ NN
	LEFT OUTER JOIN V_REZERVAC VR ON VR.ID_PRIVEZ = NN.ID_PRIVEZ
);

insert into verzije_baza (id, dt_vpis, verzija, ver_nr, opis) 
values 
(371, SYSDATE, '5.5', 291, 'Popravek prikaza trenutne situacije marine in popravki pogledov za rezervacije');


